@@ -5,11 +5,18 @@ from tqdm import tqdm
 from torchyolo.tracker.tracker_zoo import load_tracker
 from torchyolo.utils.config_utils import get_config
 from torchyolo.utils.dataset import LoadData, create_video_writer
+from torchyolo.utils.download import attempt_download_from_hub
 from torchyolo.utils.object_vis import video_vis
 
 
 class Yolov8DetectionModel:
-    def __init__(self, config_path: str):
+    def __init__(
+        self,
+        config_path: str,
+        model_path: str = "yolov8s.pt",
+    ):
+
+        self.model_path = model_path
         self.load_config(config_path)
         self.load_model()
 
@@ -23,15 +30,24 @@ class Yolov8DetectionModel:
         self.image_size = config.DETECTOR_CONFIG.IMAGE_SIZE
         self.save = config.DATA_CONFIG.SAVE
         self.show = config.DATA_CONFIG.SHOW
+        self.hf_model = config.DETECTOR_CONFIG.HUGGING_FACE_MODEL
 
-    def load_model(self, model_path: str = "yolov8s.pt"):
+    def load_model(self):
         try:
             from ultralytics import YOLO
 
-            model = YOLO(model_path)
-            model.conf = self.conf
-            model.iou = self.iou
-            self.model = model
+            if self.hf_model:
+                hf_model_path = attempt_download_from_hub(self.model_path)
+                model = YOLO(hf_model_path)
+                model.conf = self.conf
+                model.iou = self.iou
+                self.model = model
+
+            else:
+                model = YOLO(self.model_path)
+                model.conf = self.conf
+                model.iou = self.iou
+                self.model = model
 
         except ImportError:
             raise ImportError('Please run "pip install ultralytics" ' "to install YOLOv8 first for YOLOv8 inference.")
